@@ -131,6 +131,7 @@ class MLFlowExperimentTypes(BaseType):
     DATA_GENERATION = "DATA_GENERATION"
     TRAIN = "TRAIN"
     EVAL = "EVAL"
+    TIMING = "TIMING"
 
 
 class MLFlowExperimentConfig:
@@ -162,3 +163,7 @@ class OpenCVImageFormats(StrEnum):
     TIFF = ".tiff"
     TIF = ".tif"
     PNG = ".png"
+
+
+class DeviceQueryTypes(StrEnum):
+    NVIDIA_SMI = auto()
